@@ -11,12 +11,7 @@ mod priv_validator_key;
 
 pub use self::{node_key::NodeKey, priv_validator_key::PrivValidatorKey};
 
-use crate::{
-    error::{Error, Kind},
-    genesis::Genesis,
-    net, node, Moniker, Timeout,
-};
-use anomaly::{fail, format_err};
+use crate::{error::Error, genesis::Genesis, net, node, Moniker, Timeout};
 use serde::{de, de::Error as _, ser, Deserialize, Serialize};
 use std::{
     collections::BTreeMap,
@@ -109,7 +104,9 @@ pub struct TendermintConfig {
 impl TendermintConfig {
     /// Parse Tendermint `config.toml`
     pub fn parse_toml<T: AsRef<str>>(toml_string: T) -> Result<Self, Error> {
-        Ok(toml::from_str(toml_string.as_ref())?)
+        let res = toml::from_str(toml_string.as_ref()).map_err(Error::toml)?;
+
+        Ok(res)
     }
 
     /// Load `config.toml` from a file
@@ -117,14 +114,8 @@ impl TendermintConfig {
     where
         P: AsRef<Path>,
     {
-        let toml_string = fs::read_to_string(path).map_err(|e| {
-            format_err!(
-                Kind::Parse,
-                "couldn't open {}: {}",
-                path.as_ref().display(),
-                e
-            )
-        })?;
+        let toml_string = fs::read_to_string(path)
+            .map_err(|e| Error::file_io(format!("{}", path.as_ref().display()), e))?;
 
         Self::parse_toml(toml_string)
     }
@@ -133,9 +124,11 @@ impl TendermintConfig {
     pub fn load_genesis_file(&self, home: impl AsRef<Path>) -> Result<Genesis, Error> {
         let path = home.as_ref().join(&self.genesis_file);
         let genesis_json = fs::read_to_string(&path)
-            .map_err(|e| format_err!(Kind::Parse, "couldn't open {}: {}", path.display(), e))?;
+            .map_err(|e| Error::file_io(format!("{}", path.display()), e))?;
 
-        Ok(serde_json::from_str(genesis_json.as_ref())?)
+        let res = serde_json::from_str(genesis_json.as_ref()).map_err(Error::serde_json)?;
+
+        Ok(res)
     }
 
     /// Load `node_key.json` file from the configured location
@@ -212,14 +205,17 @@ impl FromStr for LogLevel {
                 global = Some(parts[0].to_owned());
                 continue;
             } else if parts.len() != 2 {
-                fail!(Kind::Parse, "error parsing log level: {}", level);
+                return Err(Error::parse(format!("error parsing log level: {}", level)));
             }
 
             let key = parts[0].to_owned();
             let value = parts[1].to_owned();
 
             if components.insert(key, value).is_some() {
-                fail!(Kind::Parse, "duplicate log level setting for: {}", level);
+                return Err(Error::parse(format!(
+                    "duplicate log level setting for: {}",
+                    level
+                )));
             }
         }
 
@@ -455,7 +451,8 @@ pub struct P2PConfig {
     /// Maximum number of outbound peers to connect to, excluding persistent peers
     pub max_num_outbound_peers: u64,
 
-    /// List of node IDs, to which a connection will be (re)established ignoring any existing limits
+    /// List of node IDs, to which a connection will be (re)established ignoring any existing
+    /// limits
     #[serde(
         serialize_with = "serialize_comma_separated_list",
         deserialize_with = "deserialize_comma_separated_list"
@@ -573,10 +570,11 @@ pub struct ConsensusConfig {
     /// Commit timeout
     pub timeout_commit: Timeout,
 
-    /// How many blocks to look back to check existence of the node's consensus votes before joining consensus
-    /// When non-zero, the node will panic upon restart
+    /// How many blocks to look back to check existence of the node's consensus votes before
+    /// joining consensus When non-zero, the node will panic upon restart
     /// if the same consensus key was used to sign {double-sign-check-height} last blocks.
-    /// So, validators should stop the state machine, wait for some blocks, and then restart the state machine to avoid panic.
+    /// So, validators should stop the state machine, wait for some blocks, and then restart the
+    /// state machine to avoid panic.
     pub double_sign_check_height: u64,
 
     /// Make progress as soon as we have all the precommits (as if TimeoutCommit = 0)
@@ -644,19 +642,20 @@ pub struct InstrumentationConfig {
 /// statesync configuration options
 #[derive(Clone, Debug, Deserialize, Serialize, PartialEq, Eq)]
 pub struct StatesyncConfig {
-    /// State sync rapidly bootstraps a new node by discovering, fetching, and restoring a state machine
-    /// snapshot from peers instead of fetching and replaying historical blocks. Requires some peers in
-    /// the network to take and serve state machine snapshots. State sync is not attempted if the node
-    /// has any local state (LastBlockHeight > 0). The node will have a truncated block history,
-    /// starting from the height of the snapshot.
+    /// State sync rapidly bootstraps a new node by discovering, fetching, and restoring a state
+    /// machine snapshot from peers instead of fetching and replaying historical blocks.
+    /// Requires some peers in the network to take and serve state machine snapshots. State
+    /// sync is not attempted if the node has any local state (LastBlockHeight > 0). The node
+    /// will have a truncated block history, starting from the height of the snapshot.
     pub enable: bool,
 
     /// RPC servers (comma-separated) for light client verification of the synced state machine and
-    /// retrieval of state data for node bootstrapping. Also needs a trusted height and corresponding
-    /// header hash obtained from a trusted source, and a period during which validators can be trusted.
+    /// retrieval of state data for node bootstrapping. Also needs a trusted height and
+    /// corresponding header hash obtained from a trusted source, and a period during which
+    /// validators can be trusted.
     ///
-    /// For Cosmos SDK-based chains, trust-period should usually be about 2/3 of the unbonding time (~2
-    /// weeks) during which they can be financially punished (slashed) for misbehavior.
+    /// For Cosmos SDK-based chains, trust-period should usually be about 2/3 of the unbonding time
+    /// (~2 weeks) during which they can be financially punished (slashed) for misbehavior.
     #[serde(
         serialize_with = "serialize_comma_separated_list",
         deserialize_with = "deserialize_comma_separated_list"
@@ -675,8 +674,8 @@ pub struct StatesyncConfig {
     /// Time to spend discovering snapshots before initiating a restore.
     pub discovery_time: Timeout,
 
-    /// Temporary directory for state sync snapshot chunks, defaults to the OS tempdir (typically /tmp).
-    /// Will create a new, randomly named directory within, and remove it when done.
+    /// Temporary directory for state sync snapshot chunks, defaults to the OS tempdir (typically
+    /// /tmp). Will create a new, randomly named directory within, and remove it when done.
     pub temp_dir: String,
 }
 
