@@ -1,13 +1,7 @@
 //! Validator private keys
 
 use crate::public_key::TendermintKey;
-use crate::{
-    account,
-    error::{Error, Kind},
-    private_key::PrivateKey,
-    public_key::PublicKey,
-};
-use anomaly::format_err;
+use crate::{account, error::Error, private_key::PrivateKey, public_key::PublicKey};
 use serde::{Deserialize, Serialize};
 use std::{fs, path::Path};
 
@@ -27,7 +21,8 @@ pub struct PrivValidatorKey {
 impl PrivValidatorKey {
     /// Parse `priv_validator_key.json`
     pub fn parse_json<T: AsRef<str>>(json_string: T) -> Result<Self, Error> {
-        let result = serde_json::from_str::<Self>(json_string.as_ref())?;
+        let result =
+            serde_json::from_str::<Self>(json_string.as_ref()).map_err(Error::serde_json)?;
 
         // Validate that the parsed key type is usable as a consensus key
         TendermintKey::new_consensus_key(result.priv_key.public_key())?;
@@ -40,14 +35,8 @@ impl PrivValidatorKey {
     where
         P: AsRef<Path>,
     {
-        let json_string = fs::read_to_string(path).map_err(|e| {
-            format_err!(
-                Kind::Parse,
-                "couldn't open {}: {}",
-                path.as_ref().display(),
-                e
-            )
-        })?;
+        let json_string = fs::read_to_string(path)
+            .map_err(|e| Error::file_io(format!("{}", path.as_ref().display()), e))?;
 
         Self::parse_json(json_string)
     }
