@@ -3,7 +3,7 @@
 use serde::{de::Error as _, Deserialize, Deserializer, Serialize};
 use subtle_encoding::base64;
 
-use crate::{account, hash::Hash, merkle, vote, Error, Kind, PublicKey, Signature};
+use crate::{account, hash::Hash, merkle, vote, Error, PublicKey, Signature};
 
 use std::convert::{TryFrom, TryInto};
 use tendermint_proto::types::SimpleValidator as RawSimpleValidator;
@@ -12,7 +12,7 @@ use tendermint_proto::types::ValidatorSet as RawValidatorSet;
 use tendermint_proto::Protobuf;
 
 /// Validator set contains a vector of validators
-#[derive(Serialize, Deserialize, Clone, Debug, PartialEq)]
+#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
 pub struct Set {
     validators: Vec<Info>,
     proposer: Option<Info>,
@@ -37,11 +37,10 @@ impl TryFrom<RawValidatorSet> for Set {
         // Ensure that the raw voting power matches the computed one
         let raw_voting_power = value.total_voting_power.try_into()?;
         if raw_voting_power != validator_set.total_voting_power() {
-            return Err(Kind::RawVotingPowerMismatch {
-                raw: raw_voting_power,
-                computed: validator_set.total_voting_power(),
-            }
-            .into());
+            return Err(Error::raw_voting_power_mismatch(
+                raw_voting_power,
+                validator_set.total_voting_power(),
+            ));
         }
 
         Ok(validator_set)
@@ -93,7 +92,7 @@ impl Set {
             .iter()
             .find(|v| v.address == proposer_address)
             .cloned()
-            .ok_or(Kind::ProposerNotFound(proposer_address))?;
+            .ok_or_else(|| Error::proposer_not_found(proposer_address))?;
 
         // Create the validator set with the given proposer.
         // This is required by IBC on-chain validation.
@@ -143,7 +142,7 @@ impl Set {
 
 /// Validator information
 // Todo: Remove address and make it into a function that generates it on the fly from pub_key.
-#[derive(Clone, Debug, PartialEq, Serialize, Deserialize, Eq)]
+#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
 pub struct Info {
     /// Validator account address
     pub address: account::Id,
@@ -170,10 +169,13 @@ impl TryFrom<RawValidator> for Info {
     fn try_from(value: RawValidator) -> Result<Self, Self::Error> {
         Ok(Info {
             address: value.address.try_into()?,
-            pub_key: value.pub_key.ok_or(Kind::MissingPublicKey)?.try_into()?,
+            pub_key: value
+                .pub_key
+                .ok_or_else(Error::missing_public_key)?
+                .try_into()?,
             power: value.voting_power.try_into()?,
             name: None,
-            proposer_priority: value.proposer_priority.try_into()?,
+            proposer_priority: value.proposer_priority.into(),
         })
     }
 }
