@@ -1,8 +1,8 @@
 use crate::chain;
+use crate::error::Error;
 use crate::Vote;
-use crate::{Error, Kind};
 use bytes::BufMut;
-use std::convert::TryFrom;
+use std::convert::{TryFrom, TryInto};
 use tendermint_proto::privval::SignedVoteResponse as RawSignedVoteResponse;
 use tendermint_proto::privval::{RemoteSignerError, SignVoteRequest as RawSignVoteRequest};
 use tendermint_proto::Error as ProtobufError;
@@ -23,13 +23,11 @@ impl TryFrom<RawSignVoteRequest> for SignVoteRequest {
     type Error = Error;
 
     fn try_from(value: RawSignVoteRequest) -> Result<Self, Self::Error> {
-        if value.vote.is_none() {
-            return Err(Kind::NoVoteFound.into());
-        }
-        Ok(SignVoteRequest {
-            vote: Vote::try_from(value.vote.unwrap())?,
-            chain_id: chain::Id::try_from(value.chain_id)?,
-        })
+        let vote = value.vote.ok_or_else(Error::no_vote_found)?.try_into()?;
+
+        let chain_id = value.chain_id.try_into()?;
+
+        Ok(SignVoteRequest { vote, chain_id })
     }
 }
 
@@ -130,7 +128,7 @@ mod tests {
             ])
             .unwrap(),
             validator_index: ValidatorIndex::try_from(56789).unwrap(),
-            signature: Signature::try_from(vec![
+            signature: Signature::new(vec![
                 130u8, 246, 183, 50, 153, 248, 28, 57, 51, 142, 55, 217, 194, 24, 134, 212, 233,
                 100, 211, 10, 24, 174, 179, 117, 41, 65, 141, 134, 149, 239, 65, 174, 217, 42, 6,
                 184, 112, 17, 7, 97, 255, 221, 252, 16, 60, 144, 30, 212, 167, 39, 67, 35, 118,
@@ -138,6 +136,7 @@ mod tests {
             ])
             .unwrap(),
         };
+
         let mut got = vec![];
 
         let request = SignVoteRequest {
@@ -215,7 +214,7 @@ mod tests {
             ])
             .unwrap(),
             validator_index: ValidatorIndex::try_from(56789).unwrap(),
-            signature: Signature::try_from(vec![
+            signature: Signature::new(vec![
                 130u8, 246, 183, 50, 153, 248, 28, 57, 51, 142, 55, 217, 194, 24, 134, 212, 233,
                 100, 211, 10, 24, 174, 179, 117, 41, 65, 141, 134, 149, 239, 65, 174, 217, 42, 6,
                 184, 112, 17, 7, 97, 255, 221, 252, 16, 60, 144, 30, 212, 167, 39, 67, 35, 118,
@@ -365,7 +364,7 @@ mod tests {
                 .unwrap(),
             }),
             // signature: None,
-            signature: Signature::try_from(vec![
+            signature: Signature::new(vec![
                 130u8, 246, 183, 50, 153, 248, 28, 57, 51, 142, 55, 217, 194, 24, 134, 212, 233,
                 100, 211, 10, 24, 174, 179, 117, 41, 65, 141, 134, 149, 239, 65, 174, 217, 42, 6,
                 184, 112, 17, 7, 97, 255, 221, 252, 16, 60, 144, 30, 212, 167, 39, 67, 35, 118,
@@ -427,7 +426,7 @@ mod tests {
                 )
                 .unwrap(),
             }),
-            signature: Signature::try_from(vec![1; ED25519_SIGNATURE_SIZE]).unwrap(),
+            signature: Signature::new(vec![1; ED25519_SIGNATURE_SIZE]).unwrap(),
         };
         let want = SignVoteRequest {
             vote,
